==> kubernetes-model-admissionregistration-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1beta1/NonResourceAttributesFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface NonResourceAttributesFluent<A extends io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<A>> extends Fluent<A> {


    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(int[] arg1,int arg2,int arg3);
    public A withNewPath(char[] arg1);
    public A withNewPath(StringBuffer arg1);
    public A withNewPath(byte[] arg1,int arg2);
    public A withNewPath(byte[] arg1);
    public A withNewPath(char[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPath(String arg1);
    public String getVerb();
    public A withVerb(String verb);
    public Boolean hasVerb();
    public A withNewVerb(StringBuilder arg1);
    public A withNewVerb(int[] arg1,int arg2,int arg3);
    public A withNewVerb(char[] arg1);
    public A withNewVerb(StringBuffer arg1);
    public A withNewVerb(byte[] arg1,int arg2);
    public A withNewVerb(byte[] arg1);
    public A withNewVerb(char[] arg1,int arg2,int arg3);
    public A withNewVerb(byte[] arg1,int arg2,int arg3);
    public A withNewVerb(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewVerb(String arg1);
}

==> kubernetes-model-admissionregistration-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1beta1/NonResourceAttributesFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface NonResourceAttributesFluent<A extends io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(int[] arg1,int arg2,int arg3);
    public A withNewPath(char[] arg1);
    public A withNewPath(StringBuffer arg1);
    public A withNewPath(byte[] arg1,int arg2);
    public A withNewPath(byte[] arg1);
    public A withNewPath(char[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3);
    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPath(String arg1);
    public String getVerb();
    public A withVerb(String verb);
    public Boolean hasVerb();
    public A withNewVerb(StringBuilder arg1);
    public A withNewVerb(int[] arg1,int arg2,int arg3);
    public A withNewVerb(char[] arg1);
    public A withNewVerb(StringBuffer arg1);
    public A withNewVerb(byte[] arg1,int arg2);
    public A withNewVerb(byte[] arg1);
    public A withNewVerb(char[] arg1,int arg2,int arg3);
    public A withNewVerb(byte[] arg1,int arg2,int arg3);
    public A withNewVerb(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewVerb(String arg1);
}
